The default end.year of 5yr ACS datasets this package uses in functions
Source:R/acsdefaultendyearhere.R
acsdefaultendyearhere.RdThis keeps track of what is available
Details
This data object is to make it easier to update the package over time by changing this in one place. It is used as the default in various functions. It should be updated as needed, along with acsfirstyearavailablehere, via pkg maintainer using script in data-raw/datacreate_acsdefaultendyearhere
See ACS 2019-2023 (released by Census Bureau 12/2024) https://www.census.gov/programs-surveys/acs/news/data-releases/2023/release.html
See ACS 2020-2024 (available from Census Bureau 12/2025) https://www.census.gov/programs-surveys/acs/news/data-releases/2024/release.html