Get the first part of the zipfile name for the ACS 5-year summary file datafiles on the US Census Bureau FTP site.
See also
get_acs_old(), get.datafile.prefix(), datafile(), geofile(), get.zipfile.prefix()
Get the first part of the zipfile name for the ACS 5-year summary file datafiles on the US Census Bureau FTP site.
get_acs_old(), get.datafile.prefix(), datafile(), geofile(), get.zipfile.prefix()