Look up ACS table IDs of tables in given sequence number files
Source:R/gettablesviaseqnums.R
gettablesviaseqnums.RdHelper function to look for which American Community Survey (ACS) tables are in given sequence files as obtained from the US Census FTP site.
See also
read.concat.states() which uses this, and get.lookup.acs() which is used by this