Skip to contents

Download and parse raw data from the Census Bureau American Community Survey (ACS) 5-year survey to get demographic data in bulk (without relying on the API). You can obtain data from the entire USA all at once (or selected FIPS), for one or more tables. This package is focused on blockgroup and tract levels of resolution.

Details

ACSdownload helps you download and parse large amounts of raw data from the Census Bureau American Community Survey 5-year datasets, providing demographic data at the blockgroup and tract levels of resolution. You can obtain data from the entire USA all at once using this package, for one or more tables.

  • The key function is get_acs_new() for ACS end years 2022 and later (the table-based summary file format).

  • For ACS end years 2021 and earlier (the older sequence-file format), this package no longer ships support; use a CRAN package such as tidycensus or the prior 2.x series of ACSdownload.

Other options for obtaining Census ACS data or related data:

Author

ejam@ejanalysis.com