Pick a year-specific table from among lookup.acs20xx objects
Source:R/get.lookup.acs.R
get.lookup.acs.RdPick a year-specific lookup table of information on American Community Survey (ACS) tables, from the Census Bureau, namely which sequence files on the FTP site contain which tables and which variables.
See also
Also see
tidycensus::load_variables()from the tidycensus package for an alternative way to get ACS data and variable info.Also see
download.lookup.acs()to download the file from the Census FTP site.Also see lookup.acs lookup.acs2021 and similar data for other years.
Also see
get_acs_new(),get.lookup.file.name(),get.url.prefix.lookup.table()